//*****************************************************************************
//  MSP-FET430F5529 - Test for Stack Overflow
//
//  Description: After a delay the function 'DummyStackFill' is called
//  which places 100 Bytes on the stack.
//
//                   MSP430
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED (5529)
//            |             P5.1|-->LED (449)
//
//  Texas Instruments, Inc
//  March 2014
//  Built with CCS V6.0
//
//*****************************************************************************

#include <msp430f5529.h>
#include <stdint.h>
#include <stdbool.h>

//*****************************************************************************
// Globals
//*****************************************************************************

// Processing loop counter
//
volatile uint16_t wLoopCounter = 0;

//*****************************************************************************
// Function prototypes
//*****************************************************************************
void delay(uint16_t value);

void main(void)
{

    //
    // Stop watchdog timer
    //
    WDTCTL = WDTPW + WDTHOLD;

    //
    // Initialize outputs
    //
    P1OUT  = 0x00;
    P5OUT  = 0x00;

    //
    // Set P1.0 and P5.1 to output direction
    //
    P1DIR |= 0x01;
    P5DIR |= 0x02;

    //
    // Run to CCR0 with SMCLK
    //
    TA0CTL = TASSEL_2 + MC_1;
    TA0CCR0 = 1000;

    //
    // Enable CCR0 and global interrupts
    //
    TA0CCTL0 = CCIE;
    _EINT();

    while(true)
    {
        wLoopCounter++;

        //
        // Toggle P1.0 and P5.1 and wait
        //
        P1OUT ^= 0x01;
        P5OUT ^= 0x02;

        delay(10000);
    }
}

void delay(uint16_t value)
{
    volatile uint16_t count = 0;

    for(count = value; count > 0; count--)
    {
    }
}

void dummyStackFill(void)
{
    //
    // Local variable is stored on the stack
    // -> 100 words are pushed to the stack
    //
    volatile uint16_t data[100] = {0};
}

#pragma vector=TIMER0_A0_VECTOR
__interrupt void isr_TACCR0()
{
    // Entrance counter
    //
    static uint16_t numEntries = 0;

    numEntries++;
    if (numEntries > 5000)
    {
        dummyStackFill();
        numEntries = 0; 
    }
}
