//*****************************************************************************
//  MSP-FET430F5529 - Breakpoint on write access to Flash
//
//  Description: This demo shows how a breakpoint can be set
//  to stop the program execution if the program tries to write
//  data to the flash.
//
//                   MSP430
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED (5529)
//            |             P5.1|-->LED (449)
//
//  Texas Instruments, Inc
//  March 2014
//  Built with CCS V6.0
//
//*****************************************************************************

#include <msp430f5529.h>
#include <stdint.h>
#include <stdbool.h>

//*****************************************************************************
// Globals
//*****************************************************************************

// Processing loop counter
//
volatile uint16_t wLoopCounter = 0;

//
// Locate in Flash
//
const uint16_t wDataInFlash = 0;

#define BSL_START    0x1000

// Function prototypes
void delay(uint16_t value);

void main(void)
{
    uint16_t iteration = 0;

    //
    // Stop watchdog timer
    //
    WDTCTL = WDTPW + WDTHOLD;

    //
    // Initialize outputs
    //
    P1OUT  = 0x00;
    P5OUT  = 0x00;

    //
    // Set P1.0 and P5.1 to output direction
    //
    P1DIR |= 0x01;
    P5DIR |= 0x02;

    //
    // Enable interrupts
    //
    _EINT();

    while(true)
    {
        wLoopCounter++;

        //
        // Toggle P1.0 and P5.1 and wait
        //
        P1OUT ^= 0x01;
        P5OUT ^= 0x02;

        delay(10000);

        iteration++;
        if (iteration == 50)
        {
            uint16_t *pwDataInFlash = (uint16_t*)&wDataInFlash;

            //
            // This will create a break - no write in Flash allowed
            // NOPs are used to show that it really was '(*pwDataInFlash)++;'
            // that caused the break - PC stops here
            //
            (*pwDataInFlash)++;
            _NOP(); _NOP(); _NOP();
        }

        if (iteration == 100)
        {
            volatile uint16_t temp;

            iteration = 0;
            //
            // This will create a break - no read from ROM allowed
            // NOPs are used to show that it really was '(temp = (*BSL_START);'
            // that caused the break - PC stops here
            //
            temp = (*(uint16_t *)BSL_START);
            _NOP(); _NOP(); _NOP();
        }
    }
}

#pragma CODE_SECTION(delay,".infoB")
void delay(uint16_t value)
{
    volatile uint16_t count = 0;

    for(count = value; count > 0; count--)
    {
    }
}
