//*****************************************************************************
//  MSP-FET430F5529 - Trace
//
//  Description: This demo shows how the Trace can
//  be used for an instruction trace to see the last
//  eight instructions the CPU has executed.
//
//                   MSP430
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED (5529)
//            |             P5.1|-->LED (449)
//
//  Texas Instruments, Inc
//  March 2014
//  Built with CCS V6.0
//
//*****************************************************************************

#include <msp430f5529.h>
#include <stdint.h>
#include <stdbool.h>

//*****************************************************************************
// Globals
//*****************************************************************************

// Processing loop counter
//
volatile uint16_t wLoopCounter = 0;

//*****************************************************************************
// Function prototypes
//*****************************************************************************
void delay(uint16_t value);

void main(void)
{

    //
    // Stop watchdog timer
    //
    WDTCTL = WDTPW + WDTHOLD;

    //
    // Initialize outputs
    //
    P1OUT  = 0x00;
    P5OUT  = 0x00;

    //
    // Set P1.0 and P5.1 to output direction
    //
    P1DIR |= 0x01;
    P5DIR |= 0x02;

    //
    // Enable interrupts
    //
    _EINT();

    while(true)
    {
        wLoopCounter++;

        //
        // Toggle P1.0 and P5.1 and wait
        //
        P1OUT ^= 0x01;
        P5OUT ^= 0x02;

        delay(10000);
    }
}

void delay(uint16_t value)
{
    volatile uint16_t count = 0;

    for(count = value; count > 0; count--)
    {
    }
}
